# Prior art

## Primary inspirations
- https://github.com/saschpe/rapport
- https://github.com/nedbat/dinghy
- https://github.com/kneth/gh-utils
- https://github.com/slackapi/slack-github-action
- https://gist.github.com/Chandler/fb7a070f52883849de35
- https://github.com/zach-snell/slack-export

## More inspirations
- https://github.com/badele/gitcheck
- https://github.com/nlitsme/githubtool
- https://github.com/badele/github-summary
- https://pypi.org/project/github-python/
- https://pypi.org/project/github-dlr/
- https://pypi.org/project/github-dl/
- https://pypi.org/project/github-crawler/
- https://pypi.org/project/github-contributions/
- https://pypi.org/project/github-context/
- https://pypi.org/project/github-contents/
- https://pypi.org/project/github-cli/
- https://pypi.org/project/github-changes/
- https://pypi.org/project/github-cards/
- https://pypi.org/project/github-bot/
- https://github.com/Chandler-Song?tab=repositories&q=github
- https://github.com/zerosoul/github-star-stats
- https://github.com/frodeaa/github_trending_archive
- https://pypi.org/project/github-bird/
- https://github.com/sigmavirus24/github3.py
  - https://github.com/domdfcoding/github3-utils
- https://pypi.org/project/github3api/
- https://pypi.org/project/github2pandas/
- https://10degres.net/github-tools-collection/
  - https://github.com/gwen001/github-search
